==> V04.061.zip: tweet_live-V04.061/web/about.php <==
<?php
/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
include_once './common.php';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">

<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>ENMI 2010 - Live Video and Annotation</title>

    <!-- Framework CSS -->
    <link rel="stylesheet" href="<?php echo(registry_url('blueprint-screen','css'));?>" type="text/css" media="screen, projection"/>
    <link rel="stylesheet" href="<?php echo(registry_url('blueprint-print','css'));?>" type="text/css" media="print"/>
    <!--[if lt IE 8]><link rel="stylesheet" href="<?php echo(registry_url('blueprint-ie','css'));?>" type="text/css" media="screen, projection"><![endif]-->
	<link rel="stylesheet" href="<?php echo(registry_url('blueprint-plugins-fancy-type','css'));?>" type="text/css" media="screen, projection"/>
	<link rel="stylesheet" href="<?php echo(registry_url('custom','css'));?>" type="text/css" media="screen, projection"/>

	<!-- FONT -->
	<link href='http://fonts.googleapis.com/css?family=PT+Sans+Narrow&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=PT+Sans&subset=latin' rel='stylesheet' type='text/css'>

	<style type="text/css">
	    .archivesTitle {margin-left:10px;}
	    .footer {margin-top:980px;}
	</style>

	<script type="text/javascript">

	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_trackPageview']);
	  _gaq.push(['_setAllowAnchor', true]);

	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();

	</script>
  </head>
  <body>
	<!--div id="sendUsFeedBack"><a href="<?php echo($C_feedback_form_url); ?>" target="_blank"><img src="<?php echo(URL_ROOT); ?>images/sendusfeedback.png"></a></div-->
    <div class="container">
     <a href="index.php">  <img src="images/ENMI_2010_logo.gif" class="logo"></a>
	  <ul class="menu">
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php?CONNECT=true" class="menuLink">
	  	<?php print $translate->_("S&apos;identifier"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php" class="menuLink">
	  	<?php print $translate->_("A propos"); ?></a></li>
	  <li ><a href="mailto:contact@iri.centrepompidou.fr" class="menuLink" >
	  	<?php print $translate->_("Contact"); ?></a></li>
	  </ul>
	  <ul class="menu">
		  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>archives.php" class="menuLink">
		  	<?php print $translate->_("Archives"); ?></a></li>
	  </ul>

	  <ul class="menu lang" >
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php echo(URL_ROOT); ?>about.php?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>



	  <div class="aboutBox">
	  <div class="archivesBoxHeader"></div>
		<div class="archivesBoxContainer">
			<!-- -->
			<h3 class="archivesTitle"><?php print $translate->_("A propos"); ?> : </h3><br/>
			<div class="span-12 prepend-1 colborder">

				<div class='AVBtitle'><?php print $translate->_("1. AboutTitle"); ?></div>
				<br/>
				<?php print $translate->_("1. AboutText"); ?>
				<br/>
			</div>


			<div class="span-8 last">
				<div class="AVBtitle"><?php print $translate->_("2. AboutIRITitle"); ?></div>
					<?php print $translate->_("2. AboutIRIText"); ?>

				<div class="AVBtitle"><?php print $translate->_("3. AboutCreditsTitle"); ?></div>
					<br/>
					<?php print $translate->_("3. AboutCreditsText"); ?>
			</div>


		</div>
		<div class="archivesBoxClear"></div>
		<div class="archivesBoxFooter"></div>
	  </div>
      <div class="footer">
		<hr>
		<a href="http://www.iri.centrepompidou.fr/" class="footerLink"> Tweet polemic </a>
		est une expérimentation de l'
		 <a href="http://www.iri.centrepompidou.fr/" class="footerLink">Institut de recherche et d’innovation </a>
		 <?php
				if (isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>D&eacute;connexion</a>");
				}
		 ?>
		  <input type="text" id="txt" size="3" style="visibility:hidden;"/>
	  </div>

    </div>


  </body>
</html>

==> V08.000.zip: tweet_live-V08.000/web/about.php <==
<?php
/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
include_once './common.php';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">

<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>Live Video and Annotation</title>

    <!-- Framework CSS -->
    <link rel="stylesheet" href="<?php echo(registry_url('blueprint-screen','css'));?>" type="text/css" media="screen, projection"/>
    <link rel="stylesheet" href="<?php echo(registry_url('blueprint-print','css'));?>" type="text/css" media="print"/>
    <!--[if lt IE 8]><link rel="stylesheet" href="<?php echo(registry_url('blueprint-ie','css'));?>" type="text/css" media="screen, projection"><![endif]-->
	<link rel="stylesheet" href="<?php echo(registry_url('blueprint-plugins-fancy-type','css'));?>" type="text/css" media="screen, projection"/>
	<link rel="stylesheet" href="<?php echo(registry_url('custom','css'));?>" type="text/css" media="screen, projection"/>

	<!-- FONT -->
	<link href='http://fonts.googleapis.com/css?family=PT+Sans+Narrow&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=PT+Sans&subset=latin' rel='stylesheet' type='text/css'>

	<style type="text/css">
	    .archivesTitle {margin-left:10px;}
	    .footer {margin-top:980px;}
	</style>

	<script type="text/javascript">

	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_trackPageview']);
	  _gaq.push(['_setAllowAnchor', true]);

	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();

	</script>
  </head>
  <body>
	<!--div id="sendUsFeedBack"><a href="<?php echo($C_feedback_form_url); ?>" target="_blank"><img src="<?php echo(URL_ROOT); ?>images/sendusfeedback.png"></a></div-->
    <div class="container">
     <a href="index.php">  <img src="images/ENMI_2010_logo.gif" class="logo"></a>
	  <ul class="menu">
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT.$C_default_rep); ?>/client.php?CONNECT=true" class="menuLink">
	  	<?php print $translate->_("S&apos;identifier"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php" class="menuLink">
	  	<?php print $translate->_("A propos"); ?></a></li>
	  <li ><a href="mailto:contact@iri.centrepompidou.fr" class="menuLink" >
	  	<?php print $translate->_("Contact"); ?></a></li>
	  </ul>
	  <ul class="menu">
		  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>archives.php" class="menuLink">
		  	<?php print $translate->_("Archives"); ?></a></li>
	  </ul>

	  <ul class="menu lang" >
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php echo(URL_ROOT); ?>about.php?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php echo(URL_ROOT); ?>about.php?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>



	  <div class="aboutBox">
	  <div class="archivesBoxHeader"></div>
		<div class="archivesBoxContainer">
			<!-- -->
			<h3 class="archivesTitle"><?php print $translate->_("A propos"); ?> : </h3><br/>
			<div class="span-12 prepend-1 colborder">

				<div class='AVBtitle'><?php print $translate->_("1. AboutTitle"); ?></div>
				<br/>
				<?php print $translate->_("1. AboutText"); ?>
				<br/>
			</div>


			<div class="span-8 last">
				<div class="AVBtitle"><?php print $translate->_("2. AboutIRITitle"); ?></div>
					<?php print $translate->_("2. AboutIRIText"); ?>

				<div class="AVBtitle"><?php print $translate->_("3. AboutCreditsTitle"); ?></div>
					<br/>
					<?php print $translate->_("3. AboutCreditsText"); ?>
			</div>


		</div>
		<div class="archivesBoxClear"></div>
		<div class="archivesBoxFooter"></div>
	  </div>
      <div class="footer">
		<hr>
		<a href="http://www.iri.centrepompidou.fr/" class="footerLink"> Tweet polemic </a>
		est une expérimentation de l'
		 <a href="http://www.iri.centrepompidou.fr/" class="footerLink">Institut de recherche et d’innovation </a>
		 <?php
				if (isset($_SESSION['SOCIAL_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>D&eacute;connexion</a>");
				}
		 ?>
		  <input type="text" id="txt" size="3" style="visibility:hidden;"/>
	  </div>

    </div>


  </body>
</html>
